@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -36,7 +36,7 @@ LdapConfigureWidgetNg::LdapConfigureWidgetNg(QWidget *parent)
     , mClientSearchConfig(new KLDAPCore::LdapClientSearchConfig)
     , mLdapModel(new KLDAPCore::LdapModel(this))
     , mLdapSortProxyModel(new KLDAPCore::LdapSortProxyModel(this))
-    , mLdapOnCurrentActivity(new QCheckBox(i18n("Show only ldap server on current activity"), this))
+    , mLdapOnCurrentActivity(new QCheckBox(i18n("Show only ldap servers on current activity"), this))
 {
     mLdapSortProxyModel->setSourceModel(mLdapModel);
     initGUI();
@@ -68,7 +68,6 @@ bool LdapConfigureWidgetNg::enablePlasmaActivities() const
 
 void LdapConfigureWidgetNg::setEnablePlasmaActivities(bool newEnablePlasmaActivities)
 {
-    mLdapSortProxyModel->setEnablePlasmaActivities(newEnablePlasmaActivities);
     mLdapOnCurrentActivity->setVisible(newEnablePlasmaActivities);
 }
 
